import { LitElement } from 'lit';
import { FontSize, FontSpacing } from '../../internal/constants/styleConstants.js';
import { ContainerThemePreference } from '../container/constants/ContainerConstants.js';
import '../drawer/arc-drawer.js';
import '../radio-group/arc-radio-group.js';
import '../radio/arc-radio.js';
import '../checkbox/arc-checkbox.js';
import '../icon/accessibility/arc-icon-accessibility.js';
import '../button/arc-button.js';
export declare type UserPreferences = {
    theme: ContainerThemePreference;
    fontSize: FontSize;
    lineHeight: FontSpacing;
    letterSpacing: FontSpacing;
    highLegibilityFonts: boolean;
    highlightLinks: boolean;
    plainText: boolean;
    stickyNotifications: boolean;
};
/**
 * @slot options - Slot to add additional options to the drawer.
 * @event arc-accessibility-change - Emitted when the user preferences change.
 *
 * @ssr - True
 */
export default class ArcAccessibility extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal - Reference to css variables that are scoped to :root. */
    private _rootCssVariables;
    /** @internal - Fallback preferences. */
    private _defaultPreferences;
    /** @internal - Available root values. */
    private _availableRootValues;
    /** @internal - State that stores the user preferences. */
    private _userPreferences;
    /** Indicates whether the drawer is open. This can be used instead of the show/hide methods. */
    open: boolean;
    handlePreferenceChange(): Promise<void>;
    connectedCallback(): void;
    show(): void;
    hide(): void;
    getThemePreference(): ContainerThemePreference;
    storeRootValues(key: keyof UserPreferences): void;
    restoreRootValues(key: keyof UserPreferences): void;
    updateRootValue(key: keyof UserPreferences, newValue: any): void;
    restoreRootDefaults(): void;
    handleOptionChange(event: MouseEvent): void;
    private radioTemplate;
    private checkBoxTemplate;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-accessibility': ArcAccessibility;
    }
}
