import { __decorate, __metadata } from "tslib";
import { html, LitElement } from 'lit';
import { property, state } from 'lit/decorators.js';
import { classMap } from 'lit/directives/class-map.js';
import { when } from 'lit/directives/when.js';
import { watch } from '../../internal/watch.js';
import { stringToInitials } from '../../internal/string.js';
import styles from './arc-avatar.styles.js';
import '../ph-icon/user/ph-icon-user.js';
/**
 * @slot icon - The default icon to use when no image or initials are present.
 *
 * @cssproperty --size - The size of the avatar.
 *
 * @ssr - True
 */
export default class ArcAvatar extends LitElement {
    constructor() {
        super(...arguments);
        /** @internal - State that keeps track whether the given image failed to load. */
        this._hasError = false;
    }
    handleImageChange() {
        this._hasError = false;
    }
    render() {
        return html `
      <div
        id="main"
        role="img"
        aria-label=${this.label}
        class=${classMap({
            avatar: true,
            'avatar--has-image': this.image && !this._hasError,
        })}
      >
        ${when(this.image && !this._hasError, () => html `<img
              id="avatar"
              src=${this.image}
              alt="Avatar"
              @error=${() => {
            this._hasError = true;
        }}
            />`, () => when(this.name, () => html `<div id="initials">${this.name}</div>`, () => html `<div id="icon">
                  <slot name="icon">
                    <ph-icon-user></ph-icon-user>
                  </slot>
                </div>`))}
      </div>
    `;
    }
}
/** @internal */
ArcAvatar.tag = 'arc-avatar';
ArcAvatar.styles = styles;
__decorate([
    state(),
    __metadata("design:type", Boolean)
], ArcAvatar.prototype, "_hasError", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcAvatar.prototype, "image", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcAvatar.prototype, "label", void 0);
__decorate([
    property({
        type: String,
        converter: (attrValue) => attrValue ? stringToInitials(attrValue) : '',
    }),
    __metadata("design:type", String)
], ArcAvatar.prototype, "name", void 0);
__decorate([
    watch('image'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], ArcAvatar.prototype, "handleImageChange", null);
//# sourceMappingURL=ArcAvatar.js.map