import { LitElement } from 'lit';
import { InputSize, ThemeColor } from '../../internal/constants/styleConstants.js';
import { ButtonType, ButtonTarget } from './constants/ButtonConstants.js';
import '../spinner/arc-spinner.js';
/**
 * @slot default - The button's label.
 * @slot prefix - Used to prepend an icon or similar element to the button.
 * @slot suffix - Used to append an icon or similar element to the button.
 *
 * @cssproperty --min-width - Set the min width of the button.
 * @cssproperty --btn-color - Overwrite the font color of the button.
 * @cssproperty --btn-background - Overwrite the background color of the button.
 *
 * @ssr - True
 */
export default class ArcButton extends LitElement {
    /** @internal */
    static tag: string;
    /** i@internal */
    static styles: import("lit").CSSResult[];
    /** @internal */
    button: HTMLButtonElement | HTMLLinkElement;
    /** @internal - Controller used to recognize form controls located inside a shadow root. */
    private readonly formController;
    /** Set the color of the button. */
    color: ThemeColor;
    /** Set the size of the button. */
    size: InputSize;
    /** Set the type of the button. */
    type: ButtonType;
    /** An optional name for the button. Ignored when `href` is set. */
    name: string;
    /** An optional value for the button. Ignored when `href` is set. */
    value: string;
    /** When set, the underlying button will be rendered as an `<a>` with this `href` instead of a `<button>`. */
    href: string;
    /** Tells the browser where to open the link. Only used when `href` is set. */
    target: ButtonTarget;
    /** Tells the browser to download the linked file as this filename. Only used when `href` is set. */
    download: string;
    /** Draws the button in an active state. */
    active: boolean;
    /** Draws the button in a disabled state. */
    disabled: boolean;
    /** Draws the button in a loading state. */
    loading: boolean;
    /** Indicates if activating the button should submit the form. Ignored when href is set. */
    submit: boolean;
    click(): void;
    focus(options?: FocusOptions): void;
    blur(): void;
    private _handleClick;
    private get isGroup();
    protected render(): import("lit-html").TemplateResult<1 | 2>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-button': ArcButton;
    }
}
