import { LitElement } from 'lit';
/**
 * @slot default - The card's body.
 * @slot header - The card's header.
 * @slot image - The card's image.
 * @slot footer - The card's footer.
 *
 * @event arc-show - Emitted when the card expands.
 * @event arc-after-show - Emitted after the cards expands and all animations are complete.
 * @event arc-hide - Emitted when the card collapses.
 * @event arc-after-hide - Emitted after the card collapses and all animations are complete.
 *
 * @ssr - True
 */
export default class ArcCard extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal */
    content: HTMLElement;
    /** @internal - Controller that listens to slot changes within the component. */
    private readonly hasSlotController;
    /** Indicates whether the card is collapsed. This can be used instead of the expand/collapse methods. Ignored when the `header` slot is not filled. */
    collapsed: boolean;
    handleCollapsedChange(): Promise<void>;
    firstUpdated(): void;
    expand(): Promise<void>;
    collapse(): Promise<void>;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-card': ArcCard;
    }
}
