import { LitElement } from 'lit';
/**
 * @slot default - The radio's label.
 *
 * @event arc-change - Emitted when the control's checked state changes.
 */
export default class ArcCheckbox extends LitElement {
    /** @internal - The component's tag */
    static tag: string;
    /** @internal - The component's styles */
    static styles: import("lit").CSSResult[];
    /** @internal - Controller used to recognize form controls located inside a shadow root. */
    private readonly formController;
    private input;
    /** The name used to reference the value of the control. */
    name: string;
    /** The value attribute of the checkbox. */
    value: string;
    /** Draws the component in a disabled state. */
    disabled: boolean;
    /** Makes the chechbox a required field. */
    required: boolean;
    /** Draws the component in a checked state. */
    checked: boolean;
    /**
     * This will be true when the control is in an invalid state. Validity in radios is determined by the message provided
     * by the `setCustomValidity` method.
     */
    invalid: boolean;
    firstUpdated(): void;
    handleDisabledChange(): void;
    handleCheckedChange(): void;
    click(): void;
    focus(options?: FocusOptions): void;
    blur(): void;
    /** Checks for validity and shows the browser's validation message if the control is invalid. */
    reportValidity(): boolean;
    /** Sets a custom validation message. If `message` is not empty, the field will be considered invalid. */
    setCustomValidity(message: string): void;
    private handleClick;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-checkbox': ArcCheckbox;
    }
}
