import { LitElement } from 'lit';
import { ContainerThemePreference, NotificationConfiguration, ActionCallback, FlyerPlacement, AlertConfiguration } from './constants/ContainerConstants.js';
import ArcAccessibility from '../accessibility/ArcAccessibility.js';
import '../navbar/arc-navbar.js';
import '../accessibility/arc-accessibility.js';
import '../bottombar/arc-bottombar.js';
import './ArcNotification.js';
import './ArcOverlay.js';
import './ArcAlert.js';
/**
 * @slot default - The container's content.
 * @slot nav - The container's navbar.
 * @slot accessibility - The accessibility drawer.
 * @slot side - The container's sidebar.
 * @slot bottom - The container's bottom bar.
 * @slot banner - The container's banner.
 *
 * @cssproperty --arc-banner-background - Set the background color of the banner.
 * @cssproperty --arc-banner-color - Set the font color of the banner.
 *
 * @ssr - True
 */
export default class ArcContainer extends LitElement {
    title: string;
    /** @internal */
    static tag: string;
    /** @internal */
    static styles: import("lit").CSSResult[];
    /** @internal */
    container: HTMLElement;
    /** @internal */
    accessibility: ArcAccessibility;
    /** @internal */
    private overlay;
    /** @internal - Reference to the preferred theme set by the app. */
    private _appPreferredTheme;
    /** Set the starting theme for the container. Once loaded, the built-in accessibility will be responsible for this property. */
    theme: ContainerThemePreference;
    /** Set the container to fullscreen mode. This hides the padding, margin and gap values. */
    fullscreen: boolean;
    /** Set the banner text. This enables the sticky banner to be rendered above the container. */
    banner: string | boolean;
    /** @bata Set the placement of the notification flyer. */
    flyerPlacement: FlyerPlacement;
    handleThemeChange(): void;
    connectedCallback(): void;
    handleAccessibilityChange(event: CustomEvent): void;
    showAccessibility(): void;
    /** @bata Open a notification. */
    dispatchNotification(config: NotificationConfiguration): [ActionCallback, ActionCallback];
    dispatchAlert(config: AlertConfiguration): ActionCallback;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-container': ArcContainer;
    }
}
