var ArcOverlay_1;
import { __decorate, __metadata } from "tslib";
import { html, css, LitElement, isServer } from 'lit';
import { customElement, state } from 'lit/decorators.js';
import { ARC_EVENTS } from '../../internal/constants/eventConstants.js';
import componentStyles from '../../styles/component.styles.js';
import '../icon-button/arc-icon-button.js';
import '../ph-icon/arrow-left/ph-icon-arrow-left.js';
import '../ph-icon/arrow-right/ph-icon-arrow-right.js';
import './ArcAlert.js';
/**
 * @bata
 * @internal component should only be created by an `ArcContainer` component
 * @ssr - True
 */
let ArcOverlay = ArcOverlay_1 = class ArcOverlay extends LitElement {
    constructor() {
        super(...arguments);
        /** @internal */
        this.activeAlertIndex = 0;
    }
    /** @internal */
    handleNextAlert() {
        var _a;
        const alerts = ((_a = this.alertElements) === null || _a === void 0 ? void 0 : _a.length) || 0;
        this.activeAlertIndex = (this.activeAlertIndex + 1) % alerts;
        this.setActiveAlert(this.activeAlertIndex);
    }
    /** @internal */
    handlePreviousAlert() {
        var _a;
        const alerts = ((_a = this.alertElements) === null || _a === void 0 ? void 0 : _a.length) || 0;
        this.activeAlertIndex = (this.activeAlertIndex - 1 + alerts) % alerts;
        this.setActiveAlert(this.activeAlertIndex);
    }
    /** @internal */
    get alertElements() {
        if (isServer)
            return undefined;
        return this.querySelectorAll('arc-alert');
    }
    /** @internal */
    setActiveAlert(index) {
        var _a;
        this.activeAlertIndex = index;
        (_a = this.alertElements) === null || _a === void 0 ? void 0 : _a.forEach((alert, i) => (alert.active = i === index));
    }
    /** Open an alert with the given configuration */
    dispatchAlert(config) {
        if (isServer)
            return () => void 0;
        /** create a new alert element */
        const alert = document.createElement('arc-alert');
        alert.config = config;
        /** append the alert to the overlay */
        config.assertive === true ? this.prepend(alert) : this.appendChild(alert);
        /** set the active alert */
        this.setActiveAlert(this.activeAlertIndex);
        /** return a callback to close the alert */
        const closeCallback = () => {
            var _a, _b;
            /** remove the event listener and element */
            alert.removeEventListener(ARC_EVENTS.hide, closeCallback);
            alert.remove();
            /** update the active alert index */
            const alerts = ((_a = this.alertElements) === null || _a === void 0 ? void 0 : _a.length) || 0;
            const index = this.activeAlertIndex;
            const newIndex = index - 1 >= 0 ? index - 1 : index + 1 >= alerts ? 0 : index + 1;
            this.setActiveAlert(newIndex);
            /** remove the overlay if there are no more alerts */
            if (((_b = this.alertElements) === null || _b === void 0 ? void 0 : _b.length) === 0) {
                this.remove();
            }
        };
        /** listen for the alert hide event */
        alert.addEventListener(ARC_EVENTS.hide, closeCallback);
        return closeCallback;
    }
    render() {
        var _a;
        const alerts = ((_a = this.alertElements) === null || _a === void 0 ? void 0 : _a.length) || 0;
        return html `
      <slot></slot>
      ${alerts > 1
            ? html `<div class="controls">
            <arc-icon-button @click=${this.handlePreviousAlert}>
              <ph-icon-arrow-left slot="icon" />
            </arc-icon-button>
            <sub>${this.activeAlertIndex + 1} / ${alerts}</sub>
            <arc-icon-button @click=${this.handleNextAlert}>
              <ph-icon-arrow-right slot="icon" />
            </arc-icon-button>
          </div>`
            : ''}
    `;
    }
};
/** @internal */
ArcOverlay.tag = 'arc-overlay';
/** @internal */
ArcOverlay.styles = [
    componentStyles,
    css `
      :host {
        display: grid;
        position: fixed;
        top: 0;
        left: 0;
        width: 100%;
        height: 100%;
        background-color: rgba(var(--arc-grey-050), 0.5);
        z-index: 1000;
        place-items: center;
      }
      div.controls {
        position: absolute;
        bottom: var(--arc-spacing-large);
        left: 50%;
        transform: translateX(-50%);
        background: rgb(var(--arc-background-color));
        border-radius: var(--arc-border-radius-small);
        padding: calc(var(--arc-spacing-x-small) / 2);
        display: grid;
        grid-template-columns: repeat(3, auto);
        align-items: center;
        gap: var(--arc-spacing-small);
      }
      ::slotted(arc-alert) {
        display: none;
      }
      ::slotted(arc-alert[active]) {
        display: block;
      }
    `,
];
__decorate([
    state({ hasChanged: () => true }),
    __metadata("design:type", Object)
], ArcOverlay.prototype, "activeAlertIndex", void 0);
ArcOverlay = ArcOverlay_1 = __decorate([
    customElement(ArcOverlay_1.tag)
], ArcOverlay);
export default ArcOverlay;
//# sourceMappingURL=ArcOverlay.js.map