import { __decorate, __metadata } from "tslib";
import { LitElement } from 'lit';
import { html } from 'lit/static-html.js';
import { property } from 'lit/decorators.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import { classMap } from 'lit/directives/class-map.js';
import { styleMap } from 'lit/directives/style-map.js';
import styles from './arc-hero.styles.js';
/**
 * @slot default - The content of the hero.
 * @slot title - The title of the hero.
 * @slot subtitle - The subtitle of the hero.
 *
 * @cssproperty --content-gap - Set the distance between the title and the content.
 *
 * @ssr - True
 */
export default class ArcHero extends LitElement {
    constructor() {
        super(...arguments);
        /** Set the banner to full screen. */
        this.fullscreen = false;
    }
    render() {
        const imageStyle = {
            background: `url(${this.background}) no-repeat center center`,
            backgroundSize: 'cover',
        };
        return html `
      <header
        id="main"
        class=${classMap({
            hero: true,
            'hero--fullscreen': this.fullscreen,
        })}
        style=${ifDefined(this.background ? styleMap(imageStyle) : undefined)}
        aria-label=${ifDefined(this.title || undefined)}
        aria-labelledby="${ifDefined(this.title ? undefined : 'title')}"
      >
        <div>
          <h1 id="title"><slot name="title">${this.title}</slot></h1>
          <slot name="subtitle">${this.subtitle}</slot>
        </div>
        <h2 id="content"><slot></slot></h2>
      </header>
    `;
    }
}
/** @internal */
ArcHero.tag = 'arc-hero';
ArcHero.styles = styles;
__decorate([
    property({ type: Boolean }),
    __metadata("design:type", Boolean)
], ArcHero.prototype, "fullscreen", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcHero.prototype, "title", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcHero.prototype, "subtitle", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcHero.prototype, "background", void 0);
//# sourceMappingURL=ArcHero.js.map