import { LitElement } from 'lit';
import { ButtonTarget } from '../button/constants/ButtonConstants.js';
import '../ph-icon/lightning/ph-icon-lightning.js';
import '../spinner/arc-spinner.js';
/**
 * @slot default - The button's label.
 *
 * @cssproperty --icon-color - Overwrite the color of the icon.
 *
 * @ssr - True
 */
export default class ArcIconButton extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal */
    button: HTMLButtonElement | HTMLLinkElement;
    /** When set, the underlying button will be rendered as an `<a>` with this `href` instead of a `<button>`. */
    href: string;
    /** Tells the browser where to open the link. Only used when `href` is set. */
    target: ButtonTarget;
    /** Tells the browser to download the linked file as this filename. Only used when `href` is set. */
    download: string;
    /** A description that gets read by screen readers and other assistive devices. For optimal accessibility, you should always include a label that describes what the icon button does. */
    label: string;
    /** Draws the button in an active state. */
    active: boolean;
    /** Draws the button in a disabled state. */
    disabled: boolean;
    /** Draws the button in a loading state. */
    loading: boolean;
    click(): void;
    focus(options?: FocusOptions): void;
    blur(): void;
    private _handleClick;
    protected render(): import("lit-html").TemplateResult<1 | 2>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-icon-button': ArcIconButton;
    }
}
