import { LitElement } from 'lit';
/**
 * @event arc-loaded - Emitted when the image is loaded.
 * @event arc-error - Emitted when the image cannot be loaded.
 *
 * @ssr - True
 */
export default class ArcImage extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal */
    container: HTMLElement;
    /** @internal */
    image: HTMLImageElement;
    /** @internal */
    loader: HTMLElement;
    /** @internal - Reference to the intersection observer. */
    private _intersectionObserver;
    /** @internal - Options that define certain aspects of the observer’s behavior. */
    private _observerOptions;
    /** @internal - Used to set a timeout on loading the image. */
    private _loadTimer;
    /** @internal - Loading state of the image. */
    private _loading;
    /** @internal - Is a valid image loaded?. */
    private _hasImage;
    /** Set the path to the image. */
    src: string;
    /** Set the alternate text for the image. */
    alt: string;
    /** Set the delay in ms before loading the image. */
    delay: number;
    /** Set the width of the image. */
    width: string;
    /** Set the height of the image. */
    height: string;
    handleSrcChange(): void;
    handleLoadingChange(): Promise<void>;
    firstUpdated(): void;
    private _attachObserver;
    private _removeObserver;
    private _handleIntersection;
    private _loadImage;
    private _imageResponse;
    handleSize(size: string): string;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-image': ArcImage;
    }
}
