import { LitElement } from 'lit';
import { ButtonTarget } from '../button/constants/ButtonConstants.js';
/**
 * @slot default - The menu item's label.
 * @slot prefix - Used to prepend an icon or similar element to the menu-item.
 * @slot suffix - Used to append an icon or similar element to the menu-item.
 *
 * @ssr - True
 */
export default class ArcMenuItem extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal */
    menuitem: HTMLButtonElement | HTMLLinkElement;
    /** A unique value to store in the menu item. This can be used as a way to identify menu items when selected. Ignored when `href` is set. */
    value: string;
    /** When set, the underlying div will be rendered as an `<a>` with this `href` instead of a `<div>`. */
    href: string;
    /** Tells the browser where to open the link. Only used when `href` is set. */
    target: ButtonTarget;
    /** Tells the browser to download the linked file as this filename. Only used when `href` is set. */
    download: string;
    /** Draws the menu item in a disabled state. */
    disabled: boolean;
    click(): void;
    firstUpdated(): void;
    private _handleClick;
    handleDisabledChange(): void;
    protected render(): import("lit-html").TemplateResult<1 | 2>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-menu-item': ArcMenuItem;
    }
}
