import { __decorate, __metadata } from "tslib";
import { LitElement } from 'lit';
import { html, literal } from 'lit/static-html.js';
import { property, query } from 'lit/decorators.js';
import { ifDefined } from 'lit/directives/if-defined.js';
import { classMap } from 'lit/directives/class-map.js';
import { watch } from '../../internal/watch.js';
import styles from './arc-menu-item.styles.js';
/**
 * @slot default - The menu item's label.
 * @slot prefix - Used to prepend an icon or similar element to the menu-item.
 * @slot suffix - Used to append an icon or similar element to the menu-item.
 *
 * @ssr - True
 */
export default class ArcMenuItem extends LitElement {
    constructor() {
        super(...arguments);
        /** Draws the menu item in a disabled state. */
        this.disabled = false;
    }
    /* Simulates a click on the button. */
    click() {
        this.menuitem.click();
    }
    firstUpdated() {
        this.setAttribute('role', 'menuitem');
    }
    /* Handle the click of the menu item */
    _handleClick(event) {
        if (this.disabled) {
            event.preventDefault();
            event.stopPropagation();
        }
    }
    handleDisabledChange() {
        this.setAttribute('aria-disabled', String(this.disabled));
    }
    render() {
        const isLink = !!this.href;
        const tag = isLink ? literal `a` : literal `div`;
        return html `
      <${tag}
        id="main"
        class=${classMap({
            'menu-item': true,
            'menu-item--disabled': this.disabled,
        })}
        value=${ifDefined(isLink ? undefined : this.value)}
        href=${ifDefined(this.href || undefined)}
        target=${ifDefined(this.target || undefined)}
        download=${ifDefined(this.download || undefined)}
        rel=${ifDefined(this.target ? 'noreferrer noopener' : undefined)}
        tabindex=${this.disabled ? '-1' : '0'}
        @click=${this._handleClick}
      >
        <span id="prefix">
          <slot name="prefix"></slot>
        </span>
        <span id="label">
          <slot></slot>
        </span>
        <span id="suffix">
          <slot name="suffix"></slot>
        </span>
      </${tag}>
    `;
    }
}
/** @internal */
ArcMenuItem.tag = 'arc-menu-item';
ArcMenuItem.styles = styles;
__decorate([
    query('#main'),
    __metadata("design:type", Object)
], ArcMenuItem.prototype, "menuitem", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcMenuItem.prototype, "value", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcMenuItem.prototype, "href", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcMenuItem.prototype, "target", void 0);
__decorate([
    property({ type: String }),
    __metadata("design:type", String)
], ArcMenuItem.prototype, "download", void 0);
__decorate([
    property({ type: Boolean, reflect: true }),
    __metadata("design:type", Boolean)
], ArcMenuItem.prototype, "disabled", void 0);
__decorate([
    watch('disabled'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], ArcMenuItem.prototype, "handleDisabledChange", null);
//# sourceMappingURL=ArcMenuItem.js.map