import { LitElement } from 'lit';
import { ActionCallback, NotificationConfiguration } from '../container/constants/ContainerConstants.js';
import '../icon-button/arc-icon-button.js';
import '../icon/accessibility/arc-icon-accessibility.js';
import '../ph-icon/list/ph-icon-list.js';
import '../ph-icon/notification/ph-icon-notification.js';
import '../dropdown/arc-dropdown.js';
import '../menu/arc-menu.js';
import '../menu-item/arc-menu-item.js';
import '../container/ArcNotification.js';
/**
 * @slot default - This slot is used to add tabs to the navbar.
 * @slot name - This slot is used to add a tool name or sub branding.
 * @slot user - This slot should be used to display the signed-in user.
 * @slot company-logo - This slot should be used to display the company logo.
 *
 * @event arc-show-accessibility - Emitted when the built-in accessibility button is pressed.
 *
 * @cssproperty --logo-height - Set the height of the tool logo.
 * @cssproperty --company-logo-color - Set the color of the company logo.
 *
 * @ssr - True
 */
export default class ArcNavbar extends LitElement {
    /** @internal */
    static tag: string;
    /** @internal */
    static styles: import("lit").CSSResult[];
    /** When set, the underlying logoWrapper will be rendered as an anchor with this property. */
    home: string;
    /** The url for the logo of the application. */
    logo: string;
    emitAccessibility(): void;
    notifications: Array<[
        NotificationConfiguration,
        ActionCallback
    ]>;
    notificationHistory: boolean;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-navbar': ArcNavbar;
    }
}
