import { LitElement } from 'lit';
/**
 * @slot default - The radio's label.
 *
 * @event arc-change - Emitted when the control's checked state changes.
 *
 * @ssr - True
 */
export default class ArcRadio extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal */
    input: HTMLInputElement;
    /** @internal - Controller used to recognize form controls located inside a shadow root. */
    private readonly formController;
    /** The name used to reference the value of the control. */
    name: string;
    /** The value attribute of the radio. */
    value: string;
    /** Draws the component in a disabled state. */
    disabled: boolean;
    /** Draws the component in a checked state. */
    checked: boolean;
    /**
     * This will be true when the control is in an invalid state. Validity in radios is determined by the message provided
     * by the `setCustomValidity` method.
     */
    invalid: boolean;
    firstUpdated(): void;
    handleDisabledChange(): void;
    handleCheckedChange(): void;
    getAllRadios(options?: {
        includeDisabled: boolean;
    }): ArcRadio[];
    getSiblingRadios(): ArcRadio[];
    click(): void;
    focus(options?: FocusOptions): void;
    blur(): void;
    /** Checks for validity and shows the browser's validation message if the control is invalid. */
    reportValidity(): boolean;
    /** Sets a custom validation message. If `message` is not empty, the field will be considered invalid. */
    setCustomValidity(message: string): void;
    private _handleClick;
    handleKeyDown(event: KeyboardEvent): void;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-radio': ArcRadio;
    }
}
