import { LitElement } from 'lit';
import '../icon-button/arc-icon-button.js';
import '../ph-icon/x/ph-icon-x.js';
import '../ph-icon/arrow-right/ph-icon-arrow-right.js';
/**
 * @slot default - The sidebar's content.
 * @slot label - The sidebar's label.
 *
 * @event arc-show - Emitted when the sidebar opens.
 * @event arc-after-show - Emitted after the sidebar opens and all animations are complete.
 * @event arc-hide - Emitted when the sidebar closes.
 * @event arc-after-hide - Emitted after the sidebar closes and all animations are complete.
 *
 * @cssproperty --gap-distance - Set the distance between sidebar elements.
 * @cssproperty --sidebar-width - Set the width of the sidebar.
 *
 * @ssr - True
 */
export default class ArcSidebar extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal */
    content: HTMLElement;
    /** Indicates whether the sidebar is open. This can be used instead of the show/hide methods. */
    open: boolean;
    /** The sidebar label. Required for proper accessibility. Alternatively, the label slot can be used. */
    label: string;
    handleOpenChange(): Promise<void>;
    show(): Promise<void> | undefined;
    hide(): Promise<void> | undefined;
    _handleClick(): void;
    handleSlots(e: any): void;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-sidebar': ArcSidebar;
    }
}
