import { LitElement } from 'lit';
import { Placement } from '@floating-ui/dom';
/**
 * @slot default - The tooltip's target element. Only the first element will be used as the target.
 * @slot content - The tooltip's content. Alternatively, you can use the content prop.
 *
 * @event arc-show - Emitted when the tooltip begins to show.
 * @event arc-after-show - Emitted after the tooltip has shown and all animations are complete.
 * @event arc-hide - Emitted when the tooltip begins to hide.
 * @event arc-after-hide - Emitted after the tooltip has hidden and all animations are complete.
 *
 * @cssproperty --max-width - Set the max width of the tooltip.
 * @cssproperty --arrow-size - Overwrite the size of the arrow.
 *
 * @ssr - True
 */
export default class ArcTooltip extends LitElement {
    /** @internal */
    static tag: string;
    static styles: import("lit").CSSResult[];
    /** @internal */
    positioner: HTMLElement;
    /** @internal */
    tooltip: HTMLElement;
    /** @internal */
    arrow: HTMLElement;
    /** @internal */
    private _target;
    /** @internal - Timeout until the hover hides. */
    private _hoverTimeout;
    /** @internal */
    private _positionerCleanup;
    /** The tooltip's content. Alternatively, you can use the content slot. */
    content: string;
    /**
     * The preferred placement of the tooltip. Note that the actual placement may vary as needed to keep the tooltip
     * inside the viewport.
     */
    placement: Placement;
    /** The distance in pixels from which to offset the tooltip away from its target. */
    distance: number;
    /** The distance in pixels from which to offset the tooltip along its target. */
    skidding: number;
    /** Set the delay in ms before showing the tooltip. */
    delay: number;
    /**
     * Controls how the tooltip is activated. Possible options include `click`, `hover`, `focus`, and `manual`. Multiple
     * options can be passed by separating them with a space. When manual is used, the tooltip must be activated
     * programmatically.
     */
    trigger: string;
    /** Indicates whether the tooltip is open. This can be used instead of the show/hide methods. */
    open: boolean;
    /** Disables the tooltip so the tooltip will not be displayed. */
    disabled: boolean;
    /** Enable this option to prevent the tooltip from being clipped when the component is placed inside a container with overflow: auto|hidden|scroll. */
    hoist: boolean;
    handlePropChange(): Promise<void>;
    handlePopoverOptionsChange(): void;
    handleDisabledChange(): void;
    connectedCallback(): void;
    firstUpdated(): Promise<void>;
    disconnectedCallback(): void;
    private startPositioner;
    private updatePositioner;
    private stopPositioner;
    show(): Promise<void> | undefined;
    hide(): Promise<void> | undefined;
    getTarget(): HTMLElement;
    hasTrigger(triggerType: string): boolean;
    handleFocus(): void;
    handleBlur(): void;
    handleClick(): void;
    handleMouseOver(): void;
    handleMouseOut(): void;
    handleKeyDown(event: KeyboardEvent): void;
    protected render(): import("lit-html").TemplateResult<1>;
}
declare global {
    interface HTMLElementTagNameMap {
        'arc-tooltip': ArcTooltip;
    }
}
